from . import test_acl
from . import test_api
from . import test_base
from . import test_basecase
from . import test_cache
from . import test_db_cursor
from . import test_expression
from . import test_float
from . import test_func
from . import test_ir_actions
from . import test_ir_attachment
from . import test_ir_http
from . import test_ir_filters
from . import test_ir_sequence
from . import test_ir_sequence_date_range
from . import test_ir_default
from . import test_mail
from . import test_menu
from . import test_mimetypes
from . import test_misc
from . import test_orm
from . import test_ormcache
from . import test_osv
from . import test_phase
from . import test_qweb
from . import test_res_config
from . import test_res_lang
from . import test_search
from . import test_translate
#import test_uninstall  # loop
from . import test_user_has_group
from . import test_view_validation
from . import test_views
from . import test_xmlrpc
from . import test_res_partner
from . import test_res_partner_bank
from . import test_reports
from . import test_non_regression
